@@ -9,7 +9,7 @@ import calendar
 import re
 
 from vulcan_athena.mirandareporting.inventory_on_hand_engine import add_columns
-from vulcan_athena.mirandareporting.setup import dataframe_tradebook, HIR
+from vulcan_athena.mirandareporting.setup import dataframe_tradebook, HIR, dataframe_cp
 
 
 def financial_status(row):
@@ -96,7 +96,6 @@ def inventory_hotfix(row):
 
 
 def shortfall_column(row, gen=False):
-
     if row['Direction'] == 'Buy':
         return 0
 
@@ -180,6 +179,10 @@ def data_combined(prospective_flag=False):
     data = dataframe_tradebook
     data = data.fillna(0)  # TODO: data issue
 
+    # Ongoing support - Request 1
+    counterparty = dataframe_cp.rename({'CounterpartyCode': 'Counterpart'}, axis=1)
+    data = data.merge(counterparty, how='left', on='Counterpart')
+
     # Issue to only consider delivered and future values #TODO: add into the code later
     if prospective_flag:
         data = data[data['Status'] != 'Prospective']
