@@ -1,8 +1,10 @@
 import pandas as pd
 import numpy as np
 import os, uuid
-from vulcan_athena.mirandareporting.setup import CONNECTION_STRING, STORAGEACCOUNTNAME, STORAGEACCOUNTKEY
+from vulcan_athena.mirandareporting.setup import CONNECTION_STRING, STORAGEACCOUNTNAME, STORAGEACCOUNTKEY, dataframe_cp
 from azure.storage.blob import BlockBlobService
+from collections import defaultdict
+import re
 
 CAL_MAPPER = {'July': 7, 'August': 8, 'September': 9, 'October': 10, 'November': 11, 'December': 12,
               'January': 1, 'February': 2, 'March': 3, 'April': 4, 'May': 5, 'June': 6}
@@ -57,6 +59,28 @@ def base_table_bus_lines(data, year, month, status=''):
     return df
 
 
+def create_client_dd():
+    counterparty_dd = defaultdict()
+
+    for idx, row in dataframe_cp.iterrows():
+        counterparty_dd[row['CounterpartyCode']] = row['CounterpartyName']
+
+    return counterparty_dd
+
+
+def return_client_name(x, counterparty_dd):
+    if (re.findall(r'\w+(?:-\w+)+', x)) and (x in counterparty_dd.keys()):
+        return counterparty_dd[x]
+    elif re.findall(r'\w+(?:-\w+)+', x):
+        return x.split('-')[0]
+    return x
+
+
+def client_drill_down(df, counterparty_dd):
+    df['Name'] = df['Name'].apply(lambda x: return_client_name(x, counterparty_dd))
+    return df
+
+
 def dashboard_files_new(master_dict, inventory_dict, deal_dict, dict_df, year):
     qantas_fp_list = ['Delivered Qantas FP', 'Future Qantas FP', 'Prospective Qantas FP']
 
@@ -91,7 +115,7 @@ def dashboard_files_new(master_dict, inventory_dict, deal_dict, dict_df, year):
                 (master_df['business_line'] == 'Qantas FP') & (master_df['Status'] == status.split()[0])]
 
             commission = (pd.pivot_table(margin_df[margin_df['Direction'] == 'Sell'], values='TEM_Margin',
-                                         index=['DealRef'], aggfunc=np.max)).reset_index()
+                                         index=['Counterpart'], aggfunc=np.max)).reset_index()
 
             if len(commission):
                 commission.columns = ['Name', 'Sale Margin']
@@ -148,7 +172,7 @@ def dashboard_files_new(master_dict, inventory_dict, deal_dict, dict_df, year):
                 (master_df['business_line'] == 'Qantas FP') & (master_df['Status'] == status.split()[0])]
 
             commission = (pd.pivot_table(margin_df[margin_df['Direction'] == 'Sell'], values='TEM_Margin',
-                                         index=['DealRef'], aggfunc=np.max)).reset_index()
+                                         index=['Counterpart'], aggfunc=np.max)).reset_index()
 
             if len(commission):
                 commission.columns = ['Name', 'Sale Margin']
@@ -157,6 +181,9 @@ def dashboard_files_new(master_dict, inventory_dict, deal_dict, dict_df, year):
                 df_list.append(base_table_bus_lines(commission, year, month, status))
 
     sales_df = pd.concat(df_list, sort=False)
+    # drill down functionality
+    # counterparty_dd = create_client_dd()
+    # sales_df = client_drill_down(sales_df, counterparty_dd)
     # sales_df.to_csv(f'base_agg_tables_tem/{year}_' + 'DealRef_Sales_Summary' + '.csv')
     blob_writer(sales_df, str(year) + 'DealRef_Sales_Summary' + '.csv')
 
@@ -181,7 +208,7 @@ def dashboard_files_new(master_dict, inventory_dict, deal_dict, dict_df, year):
             if len(margin_df):
                 if 'TEM_Margin' in margin_df.keys():
                     commission = (pd.pivot_table(margin_df[margin_df['Direction'] == 'Sell'], values='TEM_Margin',
-                                                 index=['DealRef'], aggfunc=np.max)).reset_index()
+                                                 index=['Counterpart'], aggfunc=np.max)).reset_index()
 
                     if len(commission):
                         commission.columns = ['Name', 'Sale Margin']
